@@ -10,7 +10,6 @@ LIB = ct.CDLL(libfile)
 C_FLOAT_P = ct.POINTER(ct.c_float)
 C_INT_P = ct.POINTER(ct.c_int)
 
-
 LIB.best_cut_single_dim.restype = ct.c_void_p
 LIB.best_cut_single_dim.argtypes = [C_FLOAT_P, C_INT_P, C_FLOAT_P, 
                                      C_FLOAT_P, C_INT_P, ct.c_int, 
@@ -18,19 +17,31 @@ LIB.best_cut_single_dim.argtypes = [C_FLOAT_P, C_INT_P, C_FLOAT_P,
                                      ct.c_bool, ct.c_bool]
 
 class ShallowTree(Tree):
+    """
+    Shallow tree constructor for explainable k-means clustering.
+    :param k: Number of clusters.
+    :param depth_factor: Weight of penalty term to disincentivize deep trees.
+    :param random_state: Random seed generator for kmeans.
+    """
 
-    def fit(self, x_data, kmeans=None, depth_factor=0.03):
-        if kmeans is None:
+    def __init__(self, k, depth_factor=0.03, random_state=None):
+        super().__init__(k, random_state=random_state)
+        self.depth_factor = depth_factor
+        self.base_tree = 'Shallow' if depth_factor else 'ExGreedy'
+
+    def fit(self, x_data, centers=None):
+        kmeans = KMeans(self.k, verbose=self.verbose, 
+                        random_state=self.random_state)
+        if centers is None:
             if self.verbose > 0:
                 print('Finding %d-means' % self.k)
-            kmeans = KMeans(self.k, verbose=self.verbose, 
-                        random_state=self.random_state, 
-                        n_init=1, max_iter=40)
             kmeans.fit(x_data)
+        else:
+            kmeans.cluster_centers_ = centers
+        
         y = np.array(kmeans.predict(x_data), dtype=np.int32)
-
         centers = np.array(kmeans.cluster_centers_, dtype=np.float64)
-        self.tree = self._fit_tree(x_data, centers, depth_factor)
+        self.tree = self._fit_tree(x_data, centers, self.depth_factor)
         self._feature_importance = np.zeros(x_data.shape[1])
         self.__fill_stats__(self.tree, x_data, y)
 
